package com.zfire.jiasm.syncdata.service;

import com.alibaba.fastjson.JSONArray;

public interface GLPPGFWebsitWorkerService {

    void extractedFSXS(JSONArray jsonArray);

    void extractedGZXS(JSONArray jsonArray);

    void extractedFSSH(JSONArray jsonArray);

    void extractedGZSH(JSONArray jsonArray);

    void extractedTMSC(JSONArray jsonArray);

    void extractedTMYP(JSONArray jsonArray);

    void inputWorkerData();
    void inputWebsitWorkerData();
}
